@@ -1,19 +1,21 @@
 """
 This module includes filters for dealing with errors in tiles.
 """
+from typing import List, Optional
+
+from tilecloud import Tile
 from tilecloud.filter.logger import Logger
 
 
 class CollectErrors:
     """
-    Create a filter for collecting tiles with errors in an attribute
-    called ``errors``.
+    Create a filter for collecting tiles with errors in an attribute called ``errors``.
     """
 
-    def __init__(self):
-        self.errors = []
+    def __init__(self) -> None:
+        self.errors: List[Tile] = []
 
-    def __call__(self, tile):
+    def __call__(self, tile: Tile) -> Tile:
         if tile and tile.error:
             self.errors.append(tile)
         return tile
@@ -24,7 +26,7 @@ class DropErrors:
     Create a filter for dropping all tiles with errors.
     """
 
-    def __call__(self, tile):
+    def __call__(self, tile: Tile) -> Optional[Tile]:
         if not tile or tile.error:
             return None
         else:
@@ -36,7 +38,7 @@ class LogErrors(Logger):
     Create a filter for logging all tiles with errors.
     """
 
-    def __call__(self, tile):
+    def __call__(self, tile: Optional[Tile]) -> Optional[Tile]:
         if tile and tile.error:
             Logger.__call__(self, tile)
         return tile
@@ -44,19 +46,19 @@ class LogErrors(Logger):
 
 class MaximumConsecutiveErrors:
     """
-    Create a filter that raises a :class:`TooManyErrors` exception
-    when there are ``max_consecutive_errors`` consecutive errors.
+    Create a filter that raises a :class:`TooManyErrors` exception when there are ``max_consecutive_errors``
+    consecutive errors.
 
-    :param max_consecutive_errors:
+        max_consecutive_errors:
         The max number of permitted consecutive errors. Once
         exceeded a :class:`TooManyErrors` exception is raised.
     """
 
-    def __init__(self, max_consecutive_errors):
+    def __init__(self, max_consecutive_errors: int):
         self.max_consecutive_errors = max_consecutive_errors
         self.consecutive_errors = 0
 
-    def __call__(self, tile):
+    def __call__(self, tile: Tile) -> Tile:
         if tile and tile.error:
             self.consecutive_errors += 1
             if self.consecutive_errors > self.max_consecutive_errors:
@@ -68,24 +70,24 @@ class MaximumConsecutiveErrors:
 
 class MaximumErrorRate:
     """
-    Create a filter that raises a :class:`TooManyErrors` exception
-    when the total error rate exceeds ``max_error_rate``.
+    Create a filter that raises a :class:`TooManyErrors` exception when the total error rate exceeds
+    ``max_error_rate``.
 
-    :param max_error_rate:
+        max_error_rate:
        The maximum error rate. Once exceeded a :class:`TooManyErrors`
        exception is raised.
-    :param min_tiles:
+        min_tiles:
        The minimum number of received tiles before a :class:`TooManyErrors`
        exception can be raised. Defaults to 8.
     """
 
-    def __init__(self, max_error_rate, min_tiles=8):
+    def __init__(self, max_error_rate: float, min_tiles: int = 8):
         self.max_error_rate = max_error_rate
         self.min_tiles = min_tiles
         self.tile_count = 0
         self.error_count = 0
 
-    def __call__(self, tile):
+    def __call__(self, tile: Tile) -> Tile:
         self.tile_count += 1
         if tile and tile.error:
             self.error_count += 1
@@ -99,19 +101,18 @@ class MaximumErrorRate:
 
 class MaximumErrors:
     """
-    Create a filter that raises a :class:`TooManyErrors` exception when
-    a number of errors is reached.
+    Create a filter that raises a :class:`TooManyErrors` exception when a number of errors is reached.
 
-    :param max_errors:
+        max_errors:
         The maximum number of errors. Once exceeded a :class:`TooManyErrors`
         exception is raised.
     """
 
-    def __init__(self, max_errors):
+    def __init__(self, max_errors: int):
         self.max_errors = max_errors
         self.error_count = 0
 
-    def __call__(self, tile):
+    def __call__(self, tile: Tile) -> Tile:
         if tile and tile.error:
             self.error_count += 1
             if self.error_count >= self.max_errors:
@@ -120,4 +121,6 @@ class MaximumErrors:
 
 
 class TooManyErrors(RuntimeError):
-    """TooManyErrors exception class."""
+    """
+    TooManyErrors exception class.
+    """
