@@ -1,13 +1,16 @@
 import time
+from typing import Optional
+
+from tilecloud import Tile
 
 
 class RateLimit:
-    def __init__(self, rate):
+    def __init__(self, rate: float):
         self.rate = rate
         self.count = 0
-        self.start = None
+        self.start: Optional[float] = None
 
-    def __call__(self, tile):
+    def __call__(self, tile: Tile) -> Tile:
         if tile:
             if self.start is None:
                 self.start = time.time()
