@@ -1,10 +1,20 @@
+from typing import Any, Dict, Optional
 from urllib.parse import urlencode
 
-from tilecloud import TileLayout
+from tilecloud import TileCoord, TileGrid, TileLayout
 
 
 class WMSTileLayout(TileLayout):
-    def __init__(self, url, layers, srs, format, tilegrid, border=0, params=None):
+    def __init__(
+        self,
+        url: str,
+        layers: str,
+        srs: str,
+        format: str,
+        tilegrid: TileGrid,
+        border: int = 0,
+        params: Optional[Dict[str, str]] = None,
+    ) -> None:
         if params is None:
             params = {}
         self.tilegrid = tilegrid
@@ -24,7 +34,7 @@ class WMSTileLayout(TileLayout):
         if params.get("FILTER", None) is not None:
             self.params["FILTER"] = params["FILTER"].format(**params)
 
-    def filename(self, tilecoord, metadata=None):
+    def filename(self, tilecoord: TileCoord, metadata: Optional[Any] = None) -> str:
         metadata = {} if metadata is None else metadata
         bbox = self.tilegrid.extent(tilecoord, self.border)
         size = tilecoord.n * self.tilegrid.tile_size + 2 * self.border
@@ -32,7 +42,7 @@ class WMSTileLayout(TileLayout):
         for k, v in metadata.items():
             if k.startswith("dimension_"):
                 params[k[len("dimension_") :]] = v
-        params["BBOX"] = "{0:f},{1:f},{2:f},{3:f}".format(*bbox)
-        params["WIDTH"] = size
-        params["HEIGHT"] = size
+        params["BBOX"] = f"{bbox[0]:f},{bbox[1]:f},{bbox[2]:f},{bbox[3]:f}"
+        params["WIDTH"] = str(size)
+        params["HEIGHT"] = str(size)
         return self.url + "?" + urlencode(params)
