@@ -1,19 +1,22 @@
 import errno
 import os
 import os.path
+from typing import Any, Iterator, Optional
 
-from tilecloud import Tile, TileStore
+from tilecloud import Tile, TileLayout, TileStore
 
 
 class FilesystemTileStore(TileStore):
-    """Tiles stored in a filesystem"""
+    """
+    Tiles stored in a filesystem.
+    """
 
-    def __init__(self, tilelayout, **kwargs):
+    def __init__(self, tilelayout: TileLayout, **kwargs: Any):
         TileStore.__init__(self, **kwargs)
         assert tilelayout is not None
         self.tilelayout = tilelayout
 
-    def delete_one(self, tile):
+    def delete_one(self, tile: Tile) -> Tile:
         try:
             filename = self.tilelayout.filename(tile.tilecoord, tile.metadata)
         except Exception as e:
@@ -23,13 +26,13 @@ class FilesystemTileStore(TileStore):
             os.remove(filename)
         return tile
 
-    def get_all(self):
+    def get_all(self) -> Iterator[Tile]:
         for tile in self.list():
-            with open(tile.path, "rb") as file:
+            with open(tile.path, "rb") as file:  # type: ignore
                 tile.data = file.read()
             yield tile
 
-    def get_one(self, tile):
+    def get_one(self, tile: Tile) -> Optional[Tile]:
         try:
             filename = self.tilelayout.filename(tile.tilecoord, tile.metadata)
         except Exception as e:
@@ -41,13 +44,13 @@ class FilesystemTileStore(TileStore):
             if self.content_type is not None:
                 tile.content_type = self.content_type
             return tile
-        except IOError as e:
+        except OSError as e:
             if e.errno == errno.ENOENT:
                 return None
             else:
                 raise
 
-    def list(self):
+    def list(self) -> Iterator[Tile]:
         top = getattr(self.tilelayout, "prefix", ".")
         for dirpath, _, filenames in os.walk(top):
             for filename in filenames:
@@ -56,8 +59,8 @@ class FilesystemTileStore(TileStore):
                 if tilecoord:
                     yield Tile(tilecoord, path=path)
 
-    def put_one(self, tile):
-        assert tile.data is not None
+    def put_one(self, tile: Tile) -> Tile:
+        assert isinstance(tile.data, bytes)
         try:
             filename = self.tilelayout.filename(tile.tilecoord, tile.metadata)
         except Exception as e:
